Hello! Thank you for helping us by reporting bugs or requesting for improvements. Before posting your issue, please quickly review the notes below to ensure opening an issue is the right choice for your case.

- If this issue is **not** a bug report or improvement request, please check the [Ladybug Tools forum](http://discourse.ladybug.tools), and start a topic there to discuss your issue. If you don't have an account on our forum, you can ask for one as noted in [this post](http://discourse.ladybug.tools/t/welcome-to-ladybug-tools-forum/8).

- If this issue is related to the Ladybug + Honeybee legacy plugins for Grasshopper, please post it to the repositories for legacy versions: [Ladybug](https://github.com/mostaphaRoudsari/ladybug), [honeybee](https://github.com/mostaphaRoudsari/honeybee). If you're not sure whether you are using the legacy Ladybug + Honeybee, see [here](http://www.ladybug.tools/about.html#14).

- If this issue is for any of the new Plus plugins, please ensure this is the correct repository for your issue. Issues that are specific to the plugin interface should be posted to the correct plugin repository. For example issues related to the Honeybee plugin for Dynamo should be posted to [honeybee-dynamo](https://github.com/ladybug-tools/honeybee-dynamo/) repository and not [honeybee](https://github.com/ladybug-tools/honeybee/).

- Finally, if you haven't done it already, please do a quick search of our existing issues and ensure that the issue has not already been posted.

If you passed all the checks above, feel free to post your issue and please respect these guidelines:
- Be clear about the error and include related information about how to re-create the issue.
- If possible, share an example file or example code for us to recreate the issue.

Thank you again for opening an issue. This will benefit all our users! ALSO DO NOT FORGET TO REMOVE ALL THESE NOTES BEFORE POSTING YOUR ISSUE.
